#!/usr/bin/env python3
# -*- coding: utf-8 -*-
#
# License: GNU General Public License v2
#
# Author: thl-cmk[at]outlook[dot]com
# URL   : https://thl-cmk.hopto.org
# Date  : 2023-05-20

# based on https://github.com/allangood/check_mk/tree/master/plugins/squid
#
# rewritten for cmk 2.x
#
# 2023-05-20: moved agent plugin from ~/local/share/check_mk/agents/plugins/linux
#                                  to ~/local/share/check_mk/agents/plugins
#             renamed bakery plugin from squid to squid.py
# 2023-09-21: moved file to ~/local/lib/check_mk/base/cee/plugins/bakery
#             fix crash if port not configured in wato
# 2023-12-02: added IP-Address option

from pathlib import Path
from cmk.base.cee.plugins.bakery.bakery_api.v1 import (
    FileGenerator,
    OS,
    Plugin,
    PluginConfig,
    register
)


def get_squid_files(conf) -> FileGenerator:
    yield Plugin(
        base_os=OS.LINUX,
        source=Path('squid'),
    )

    yield PluginConfig(
        base_os=OS.LINUX,
        lines=[f'{key}={value}' for key, value in conf.items()],
        # lines=[
        #     f'port={conf.get("port", 3128)}',
        #     f'ip_address={conf.get("ip_address", "localhost")}'
        # ],
        target=Path('squid.cfg'),
        include_header=False,
    )




register.bakery_plugin(
    name='squid',
    files_function=get_squid_files,
)
